# CKOKER.MAK, Version 3.03
# See CKOMAK.HLP for further information.
# Authors: 
#   Kai Uwe Rommel, Muenchen (Munich), Germany
#   Frank da Cruz, Columbia University, New York City, USA
#   Jeffrey Altman, Altmania Productions, NY
#   Michael Godfrey, Stanford University, CA
# Last update: Wed Jun  1 16:56:45 1994
#
# -- Makefile to build C-Kermit 5A(190) for OS/2 --
#
# The result is a runnable program called CKOKER.EXE in the current directory.
#
# The 32-bit versions run only on OS/2 2.00 or higher.

#---------- Compiler targets:
#
# To build: "[dn]make -f ckoker.mak <target>"

unknown:
	@echo Please specify target: "msc ibmc gcc"

# Microsoft C 6.00 (16-bit):
#
# When (if) the LINK step doesn't work: (a) make sure the MSC directories are
# ahead of the OS/2 directories in your PATH; (b) if LINK complains about not
# finding LLIBCEP.LIB (because NMAKE inserted "/NOD:LLIBCE.LIB LLIBCEP.LIB"
# into the LINK options), just tell it to use LLIBCE.LIB.
# 
# LINK might also ask you about TCPIPDLL.LIB.  If you don't have one,
# just hit Enter.
#
# Warning: If the compiler complains about "Unrecoverable heap overflow", in
# Pass x, add the -BxCxL option after -W2, within the quotes; for example, for
# Pass 3, add -B3C3L.  This requires CxL.EXE on disk (e.g. C3L.EXE for Pass 3).
#

#    IMPORTANT: When building with TCP/IP support, edit the IBM-supplied
#    TCPIP\INCLUDE\NETLIB.H to remove the spurious #define for SIGALRM!

# release version
msc:
	$(MAKE) -f ckoker.mak all16 \
	CC="cl -nologo -W2 -B2C2L -B3C3L -Od -FPc -AL" OUT="-o" O=".obj" \
	OPT="-Ot -B2C2L -B3C3L" DEBUG="-Gs" DLL="-Alfw -Gs -Lp" \
	CFLAGS="-Au -J -Zap -G2 -Gt8 -UMSDOS" \
	LDFLAGS="-F 9A00 -Lp -link /noe /packc /packd /exep" \
	DEF="ckoker.def"

# debugging version
mscd:
	$(MAKE) -f ckoker.mak all16 \
	CC="cl -nologo -W2 -Od -FPc -AL" OUT="-o" O=".obj" \
	OPT="" DEBUG="-Zi" DLL="-Alfw -Gs -Lp" \
	CFLAGS="-B2C2L -B3C3L -Au -J -Zap -G2 -Gt8 -UMSDOS" \
	LDFLAGS="-F 9A00 -Lp -link /noe /packc /packd /exep" \
	DEF="ckoker.def"

# IBM C Set++ 2.x (32-bit) with static linking -- no DLL's required.
# Which is good, because otherwise users would need to have the IBM
# OS/2 development system C libraries on their PCs.
# - Current CSDs are CTC0009 and CTU0002
# - Current LINK386 is 2.01.012
#
# Except the TCP/IP support is linked dynamically.  A dummy TCP/IP DLL is
# produced for those who do not have TCP/IP installed.  TCP/IP is not linked
# statically because IBM keeps issuing CSDs for it, so this way C-Kermit gets
# the TCP/IP fixes automatically without having to be rebuilt.  Also, dynamic
# linking keeps the size of the .EXE down.
#
# -G4 optimizes for the i486 pipeline.  It might make the program run a bit
# faster on 486 and above, but it also increases the size of .EXE by about
# 30K.  The result still runs OK on i386 processors.
# Add -G4 to the CC= line below if you want i486 optimization.
#
# msgbind does not use any environment variables to find DDE4.MSG.  Therefore,
# its path (on the system where you are building C-Kermit) must be edited into
# CKOKER.MSB, or the DDE4.MSG file must be copied into the current directory.
# It is normally found in IBMCPP\HELP.

# release version
ibmc:
	$(MAKE) -f ckoker.mak all32 \
	CC="icc -q -Sm -Gm -Gt" OUT="-Fe" O=".obj" \
	OPT="-O" DEBUG="-Gs" DLL="-Gt- -Gs" \
	CFLAGS="-Sp1 -D__STDC__" LDFLAGS="" \
	DEF="ckoker32.def"
	msgbind ckoker.msb

# profiling version
ibmcp:
	$(MAKE) -f ckoker.mak all32 \
	CC="icc -q -Sm -Gm -Gt" OUT="-Fe" O=".obj" \
	OPT="-O" DEBUG="-Gs -Gh -Ti" DLL="-Gt- -Gs" \
	CFLAGS="-Sp1 -D__STDC__" LDFLAGS="dde4xtra.obj" \
	DEF="ckoker32.def"
	msgbind ckoker.msb

# debugging version
ibmcd:
	$(MAKE) -f ckoker.mak all32 \
	CC="icc -q -Sm -Gm -Gt" OUT="-Fe" O=".obj" \
	OPT="" DEBUG="-Ti -D__DEBUG" DLL="-Gt- -Gs" \
	CFLAGS="-Sp1 -D__STDC__" LDFLAGS="" \
	DEF="ckoker32.def"
	msgbind ckoker.msb

# emx 0.8f + gcc 2.3.3 (32-bit)

# release version
gcc:
	$(MAKE) -f ckoker.mak all32 \
	CC="gcc -Zomf" OUT="-o" O=".obj" \
	OPT="-O" DEBUG="-s" DLL="-Zdll" \
	CFLAGS="" LDFLAGS="" \
	DEF="ckoker32.def"

# debugging version
gccd:
	$(MAKE) -f ckoker.mak all32 \
	CC="gcc" OUT="-o" O=".o" \
	OPT="" DEBUG="-g" DLL="-Zdll" \
	CFLAGS="" LDFLAGS="" \
	DEF="ckoker32.def"

#---------- Macros:

# To add mouse support (32-bit version only) add -DOS2MOUSE to DEFINES.
# (presently omitted because it is not yet working right).

# To build without TCP/IP support, uncomment the following line and
# then comment out the next:
# DEFINES = -DOS2 -DDYNAMIC -DKANJI -DNETCONN -DDECNET -DNPIPE

# To build with TCP/IP support, uncomment the following three 
# lines and comment out the previous set:
DEFINES = -DOS2 -DDYNAMIC -DKANJI -DNETCONN -DDECNET -DTCPSOCKET -DNPIPE \
          -DOS2MOUSE -DCK_NETBIOS      

LIBS = rexx.lib 

#...Frank's, for IBM TCP/IP 1.2.1
TCPLIBS = tcpipdll.lib

#...Jeff's
# for IBM TCP/IP 1.2.1
#TCPLIBS = tcpipdll.lib
# for IBM TCP/IP 2.0
#TCPLIBS = tcp32dll.lib so32dll.lib

# Kai-Uwe's
# for IBM TCP/IP 1.2.1
#TCPINC = d:/tcpip/include16
#TCPLIBS = tcpipdll.lib
# for IBM TCP/IP 2.0
#TCPINC = d:/tcpip/include
#TCPLIBS = tcp32dll.lib so32dll.lib

#---------- Inference rules:

.SUFFIXES: .w .c $(O)

.c$(O):
	$(CC) $(CFLAGS) $(DEBUG) $(OPT) $(DEFINES) -c $*.c

#---------- Targets:

OBJS =	ckcmai$(O) ckcfns$(O) ckcfn2$(O) ckcfn3$(O) ckcpro$(O) \
        ckuxla$(O) ckucmd$(O) ckuusr$(O) ckuus2$(O) ckuus3$(O) \
        ckuus4$(O) ckuus5$(O) ckuus6$(O) ckuus7$(O) ckuusx$(O) \
	ckuusy$(O) ckudia$(O) ckuscr$(O) ckufio$(O) ckocon$(O) \
        ckotio$(O) ckonet$(O) ckcnet$(O) ckonbi$(O) 

all32: ckoker32.exe ckotcp32.dll

all16: ckoker16.exe ckotcp16.dll

ckoker32.exe: $(OBJS) $(DEF)
	$(CC) $(DEBUG) $(OBJS) $(DEF) $(OUT) $@ $(LIBS) $(LDFLAGS)

ckoker16.exe: $(OBJS) $(DEF)
	$(CC) $(DEBUG) $(OBJS) $(DEF) $(OUT) $@ $(LIBS) $(LDFLAGS)

ckotcp32.dll: ckotcp.obj ckotcp32.def
	$(CC) $(DEBUG) $(DLL) ckotcp.obj ckotcp32.def $(OUT) $@ $(TCPLIBS)

ckotcp16.dll: ckotcp.obj ckotcp16.def
	$(CC) $(DEBUG) $(DLL) ckotcp.obj ckotcp16.def $(OUT) $@ $(TCPLIBS)

ckwart.exe: ckwart$(O) $(DEF)
	$(CC) $(DEBUG) ckwart$(O) $(DEF) $(OUT) $@ $(LIBS) $(LDFLAGS)

#---------- Dependencies:

ckcmai$(O):	ckcmai.c ckcker.h ckcdeb.h ckcasc.h ckcsym.h ckcnet.h ckonet.h
ckcfns$(O):	ckcfns.c ckcker.h ckcdeb.h ckcasc.h ckcsym.h ckcxla.h ckuxla.h
ckcfn2$(O):	ckcfn2.c ckcker.h ckcdeb.h ckcasc.h ckcsym.h ckcxla.h ckuxla.h
ckcfn3$(O):	ckcfn3.c ckcker.h ckcdeb.h ckcasc.h ckcsym.h ckcxla.h ckuxla.h
ckcpro$(O):	ckcpro.c ckcker.h ckcdeb.h ckcasc.h
ckuxla$(O):	ckuxla.c ckcker.h ckcdeb.h ckcxla.h ckuxla.h
ckucmd$(O):	ckucmd.c ckcker.h ckcdeb.h ckcasc.h ckucmd.h
ckudia$(O):	ckudia.c ckcker.h ckcdeb.h ckcasc.h ckucmd.h
ckuscr$(O):	ckuscr.c ckcker.h ckcdeb.h ckcasc.h
ckuusr$(O):	ckuusr.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h ckucmd.h \
		  ckcxla.h ckuxla.h ckcnet.h ckonet.h
ckuus2$(O):	ckuus2.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h ckucmd.h \
		  ckcxla.h ckuxla.h
ckuus3$(O):	ckuus3.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h ckucmd.h \
		  ckcxla.h ckuxla.h ckcnet.h ckonet.h ckonbi.h
ckuus4$(O):	ckuus4.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h ckucmd.h \
		  ckcxla.h ckuxla.h ckuver.h ckcnet.h ckonet.h
ckuus5$(O):	ckuus5.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h ckucmd.h
ckuus6$(O):	ckuus6.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h ckucmd.h
ckuus7$(O):	ckuus7.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h ckucmd.h \
		  ckcxla.h ckuxla.h ckcnet.h ckonet.h
ckuusx$(O):	ckuusx.c ckcker.h ckcdeb.h ckcasc.h ckuusr.h
ckuusy$(O):	ckuusy.c ckcker.h ckcdeb.h ckcasc.h
ckufio$(O):	ckufio.c ckcker.h ckcdeb.h ckuver.h ckodir.h ckoker.h

ckocon$(O):	ckocon.c ckcker.h ckcdeb.h ckcasc.h ckoker.h ckocon.h ckonbi.h
ckotio$(O):	ckotio.c ckcker.h ckcdeb.h ckuver.h ckodir.h ckoker.h

ckcnet$(O):	ckcnet.c ckcker.h ckcdeb.h ckcnet.h ckonet.h ckotcp.h
ckonet$(O):	ckonet.c ckcker.h ckcdeb.h ckoker.h ckcnet.h ckonet.h \
                ckotcp.h ckonbi.h
ckonbi$(O):     ckonbi.c ckonbi.h ckcdeb.h 

ckcpro.c:	ckcpro.w
		$(MAKE) -f ckoker.mak ckwart.exe \
		  CC="$(CC)" OUT="$(OUT)" O="$(O)" OPT="$(OPT)" \
		  DEBUG="$(DEBUG)" CFLAGS="$(CFLAGS)" LDFLAGS="$(LDFLAGS)"
		ckwart ckcpro.w ckcpro.c

ckotcp$(O): ckotcp.c ckotcp.h
	$(CC) $(CFLAGS) $(DEBUG) $(OPT) $(DLL) -c $*.c

